==> concerto-1.8.3-NoCAS.tar.gz: concerto-1.8.3-NoCAS/admin/app/groups/list.php <==
<?php
/**
 * This file was developed as part of the Concerto digital signage project
 * at RPI.
 *
 * Copyright (C) 2009 Rensselaer Polytechnic Institute
 * (Student Senate Web Technologies Group)
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.  You should have received a copy
 * of the GNU General Public License along with this program.
 *
 * @package      Concerto
 * @author       Web Technologies Group, $Author: brian $
 * @copyright    Rensselaer Polytechnic Institute
 * @license      GPLv2, see www.gnu.org/licenses/gpl-2.0.html
 * @version      $Revision: 558 $
 */
?><?php if(isAdmin()) { ?>
<a href="<?=ADMIN_URL.'/groups/new' ?>"><span class="buttonsel"><div class="buttonleft"><img src="<?= ADMIN_BASE_URL ?>/images/buttonsel_left.gif" border="0" alt="" /></div><div class="buttonmid"><div class="buttonmid_padding">New Group</div></div><div class="buttonright"><img src="<?= ADMIN_BASE_URL ?>/images/buttonsel_right.gif" border="0" alt="" /></div></span></a><div style="clear:both;height:12px;"></div>
<? } ?>
<h2>Click on a group for more information.</h2>
<table class="edit_win" cellpadding="6" cellspacing="0">
<?php
if(is_array($this->groups))
foreach($this->groups as $groupid => $group){
   ?>
<tr>
   <td<? if (!$notfirst) {$notfirst =1;  echo ' class="firstrow"';} ?>>
   <h1><a href="<?= ADMIN_URL?>/groups/show/<? echo $groupid ?>"><?= $group[name] ?></a></h1>
      <p><?= $group[members] ?> member<?=$group[members]!=1?"s":""?></p>
      <?php if(is_array($group[controls]))
        echo "<p>Controls ".join(" and ", $group[controls]).'</p>';
      ?>
   </td>
</tr>

<?php
}
?>
</table>

==> concerto-1.9.2-NoCAS.tar.gz: concerto-1.9.2-NoCAS/admin/app/groups/list.php <==
<?php
/**
 * This file was developed as part of the Concerto digital signage project
 * at RPI.
 *
 * Copyright (C) 2009 Rensselaer Polytechnic Institute
 * (Student Senate Web Technologies Group)
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.  You should have received a copy
 * of the GNU General Public License along with this program.
 *
 * @package      Concerto
 * @author       Web Technologies Group, $Author: brian $
 * @copyright    Rensselaer Polytechnic Institute
 * @license      GPLv2, see www.gnu.org/licenses/gpl-2.0.html
 * @version      $Revision: 712 $
 */
?><?php if(isAdmin()) { ?>
<a href="<?=ADMIN_URL.'/groups/new' ?>"><span class="buttonsel"><div class="buttonleft"><img src="<?= ADMIN_BASE_URL ?>/images/buttonsel_left.gif" border="0" alt="" /></div><div class="buttonmid"><div class="buttonmid_padding">New Group</div></div><div class="buttonright"><img src="<?= ADMIN_BASE_URL ?>/images/buttonsel_right.gif" border="0" alt="" /></div></span></a><div style="clear:both;height:12px;"></div>
<? } ?>
<h2>Click on a group for more information.</h2>
<table class="edit_win" cellpadding="6" cellspacing="0">
<?php
$notfirst = 0; //Indicate that this isn't not the first group, until we display a group 
if(is_array($this->groups))
foreach($this->groups as $groupid => $group){
   ?>
<tr>
   <td<? if (!$notfirst) {$notfirst =1;  echo ' class="firstrow"';} ?>>
   <h1><a href="<?= ADMIN_URL?>/groups/show/<? echo $groupid ?>"><?= $group['name'] ?></a></h1>
      <p><?= $group['members'] ?> member<?=$group['members']!=1?"s":""?></p>
      <?php if(is_array($group['controls']))
        echo "<p>Controls ".join(" and ", $group['controls']).'</p>';
      ?>
   </td>
</tr>

<?php
}
?>
</table>
